Radpress
========
Radpress is a simple blogging application for Djangonauts. It uses
`restructuredtext`_ format for articles and pages.

Installation
------------
You can install **radpress** ``pip`` or ``easy_install``. If you want to
fork and develop the project, create a virtual environment and install it
with::

    python setup.py install

Authors
-------
Gökmen Görgen, <gokmen[@]radity.com>

.. _restructuredtext: http://docutils.sourceforge.net/rst.html
